# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


class HostTags(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "host": (str,),
            "tags": ([str],),
        }

    attribute_map = {
        "host": "host",
        "tags": "tags",
    }

    def __init__(self, *args, **kwargs):
        """
        Set of tags to associate with your host.

        :param host: Your host name.
        :type host: str, optional

        :param tags: A list of tags to apply to the host.
        :type tags: [str], optional
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(HostTags, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self
